rule selectMappedISBP:
	message: " Select only mapped ISBPS on new refseq"
	input: mapped=config['results']+'/1.filteredISBPs.sorted.bed', original=config['isbpBed']
	output: config['results']+'/2.mappedISBPs_coordsOnQuery.bed'
	log: config['results']+'/2.mappedISBPs_coordsOnQuery.log'
	shell:
		"""
		cut -f 4 {input.mapped}|fgrep -wf - {input.original} |sort -k1,1 -k2,2n 1> {output} 2> {log}
		"""

rule upstreamClosest:
	message: " Collect closest marker upstream of genes"
	input: annot=config['results']+"/1.features.bed", markers=config['results']+'/2.mappedISBPs_coordsOnQuery.bed'
	output: temp(config['results']+'/2.closestbedUpstream.txt')
	log: config['results']+"/2.closestbedUpstream.log"
	shell:
		"""
		bedtools closest -id -D ref -io -a {input.annot} -b {input.markers} 1> {output} 2> {log}
		"""

rule downstreamClosest:
	message: " Collect Downstream marker upstream of genes"
	input: annot=config['results']+"/1.features.bed", markers=config['results']+'/2.mappedISBPs_coordsOnQuery.bed'
	output: temp(config['results']+'/2.downstreamClosest.txt')
	log: config['results']+"/2.downstreamClosest.log"
	shell:
		"""
		bedtools closest -iu -D ref -io -a {input.annot} -b {input.markers} 1> {output} 2> {log}
		"""

rule mergeClosest:
	message: " Merge both upstream and downstream results"
	input: up=config['results']+'/2.closestbedUpstream.txt', down=config['results']+'/2.downstreamClosest.txt'
	output: config['results']+'/2.mergedClosestMarkers.txt'
	log: config['results']+'/2.mergedClosestMarkers.log'
	shell:
		"""
		join -1 4 -2 4 <(sort -k4,4 {input.up}) <(sort -k4,4 {input.down})|sed "s/ /\t/g"|cut -f -11,17- |sort -k2,2 -k3,3n |awk "{{size=\$14-\$8;print \$0,size}}"|sed "s/ /\t/g" 1> {output} 2> {log}
		"""